//+------------------------------------------------------------------+
//|                                                     RSI 3X13.mq4 |
//|                                                 Pipi Brasci corp |
//|                                             https://www.mql5.com |
//+------------------------------------------------------------------+
#property copyright "Pipi Brasci corp"
#property link      "https://www.mql5.com"
#property version   "1.00"
#property description ""
#property tester_indicator "Fisher_Yur4ik_Alert_v1"

#include <stdlib.mqh>
#include <stderror.mqh>

//--- indicator settings
#property indicator_chart_window
#property indicator_buffers 2

#property indicator_type1 DRAW_ARROW
#property indicator_width1 0
#property indicator_color1 0xFFAA00
#property indicator_label1 "RSI3x13 BUY"

#property indicator_type2 DRAW_ARROW
#property indicator_width2 0
#property indicator_color2 0x1E00FF
#property indicator_label2 "RSI3xRSI13 SELL"

//--- indicator buffers
double Buffer1[];
double Buffer2[];

extern double Buy_Arrow_Distance = 1;
extern double Sell_Arrow_Distance = 1;
extern double RSIValue_High = 70;
extern double RSIValue_Low = 30;
datetime time_alert; //used when sending alert
extern bool Audible_Alerts = true;
double myPoint; //initialized in OnInit

void myAlert(string type, string message)
  {
   if(type == "print")
      Print(message);
   else if(type == "error")
     {
      Print(type+" | RSI 3 x13 @ "+Symbol()+","+IntegerToString(Period())+" | "+message);
     }
   else if(type == "order")
     {
     }
   else if(type == "modify")
     {
     }
   else if(type == "indicator")
     {
      Print(type+" | RSI 3 x13 @ "+Symbol()+","+IntegerToString(Period())+" | "+message);
      if(Audible_Alerts) Alert(type+" | RSI 3 x13 @ "+Symbol()+","+IntegerToString(Period())+" | "+message);
     }
  }

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int OnInit()
  {   
   IndicatorBuffers(2);
   SetIndexBuffer(0, Buffer1);
   SetIndexEmptyValue(0, EMPTY_VALUE);
   SetIndexArrow(0, 233);
   SetIndexBuffer(1, Buffer2);
   SetIndexEmptyValue(1, EMPTY_VALUE);
   SetIndexArrow(1, 234);
   //initialize myPoint
   myPoint = Point();
   if(Digits() == 5 || Digits() == 3)
     {
      myPoint *= 10;
     }
   return(INIT_SUCCEEDED);
  }

//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int OnCalculate(const int rates_total,
                const int prev_calculated,
                const datetime& time[],
                const double& open[],
                const double& high[],
                const double& low[],
                const double& close[],
                const long& tick_volume[],
                const long& volume[],
                const int& spread[])
  {
   int limit = rates_total - prev_calculated;
   //--- counting from 0 to rates_total
   ArraySetAsSeries(Buffer1, true);
   ArraySetAsSeries(Buffer2, true);
   //--- initial zero
   if(prev_calculated < 1)
     {
      ArrayInitialize(Buffer1, EMPTY_VALUE);
      ArrayInitialize(Buffer2, EMPTY_VALUE);
     }
   else
      limit++;
   
   //--- main loop
   for(int i = limit-1; i >= 0; i--)
     {
      if (i >= MathMin(1000-1, rates_total-1-50)) continue; //omit some old rates to prevent "Array out of range" or slow calculation   
      
      //Indicator Buffer 1
      if(iRSI(NULL, PERIOD_CURRENT, 3, PRICE_CLOSE, i) > iRSI(NULL, PERIOD_CURRENT, 13, PRICE_CLOSE, i)
      && iRSI(NULL, PERIOD_CURRENT, 3, PRICE_CLOSE, i+1) < iRSI(NULL, PERIOD_CURRENT, 13, PRICE_CLOSE, i+1) //Relative Strength Index crosses above Relative Strength Index
      && iCustom(NULL, PERIOD_CURRENT, "Fisher_Yur4ik_Alert_v1", 10, false, false, false, false, "alert2.wav", 0, 0, i) > 0 //Fisher_Yur4ik_Alert_v1 > fixed value
      && iRSI(NULL, PERIOD_CURRENT, 13, PRICE_CLOSE, i) >= RSIValue_Low //Relative Strength Index >= fixed value
      )
        {
         Buffer1[i] = Low[i] - Buy_Arrow_Distance * myPoint; //Set indicator value at Candlestick Low - fixed value
         if(i == 0 && Time[0] != time_alert) { myAlert("indicator", "RSI3x13 BUY"); time_alert = Time[0]; } //Instant alert, only once per bar
        }
      else
        {
         Buffer1[i] = EMPTY_VALUE;
        }
      //Indicator Buffer 2
      if(iRSI(NULL, PERIOD_CURRENT, 3, PRICE_CLOSE, i) < iRSI(NULL, PERIOD_CURRENT, 13, PRICE_CLOSE, i)
      && iRSI(NULL, PERIOD_CURRENT, 3, PRICE_CLOSE, i+1) > iRSI(NULL, PERIOD_CURRENT, 13, PRICE_CLOSE, i+1) //Relative Strength Index crosses below Relative Strength Index
      && iCustom(NULL, PERIOD_CURRENT, "Fisher_Yur4ik_Alert_v1", 10, false, false, false, false, "alert2.wav", 0, 0, i) < 0 //Fisher_Yur4ik_Alert_v1 < fixed value
      && iRSI(NULL, PERIOD_CURRENT, 13, PRICE_CLOSE, i) <= RSIValue_High //Relative Strength Index <= fixed value
      )
        {
         Buffer2[i] = High[i] + Sell_Arrow_Distance * myPoint; //Set indicator value at Candlestick High + fixed value
         if(i == 0 && Time[0] != time_alert) { myAlert("indicator", "RSI3xRSI13 SELL"); time_alert = Time[0]; } //Instant alert, only once per bar
        }
      else
        {
         Buffer2[i] = EMPTY_VALUE;
        }
     }
   return(rates_total);
  }
//+------------------------------------------------------------------+